@@ -716,7 +716,7 @@ add_account (GoaProvider    *provider,
           accept_ssl_errors = FALSE;
         }
 
-      markup = g_strdup_printf ("<b>%s:</b> %s",
+      markup = g_strdup_printf ("<b>%s:</b>\n%s",
                                 _("Error connecting to Microsoft Exchange server"),
                                 data.error->message);
       g_clear_error (&data.error);
@@ -890,7 +890,7 @@ refresh_account (GoaProvider    *provider,
     {
       gchar *markup;
 
-      markup = g_strdup_printf ("<b>%s:</b> %s",
+      markup = g_strdup_printf ("<b>%s:</b>\n%s",
                                 _("Error connecting to Microsoft Exchange server"),
                                 data.error->message);
       g_clear_error (&data.error);
