@@ -29,6 +29,7 @@
 #include <json-glib/json-glib.h>
 
 #include "goaprovider.h"
+#include "goaprovider-priv.h"
 #include "goaoauthprovider.h"
 #include "goaflickrprovider.h"
 
@@ -60,6 +61,7 @@ struct _GoaFlickrProviderClass
  */
 
 G_DEFINE_TYPE_WITH_CODE (GoaFlickrProvider, goa_flickr_provider, GOA_TYPE_OAUTH_PROVIDER,
+                         goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
 							 g_define_type_id,
 							 "flickr",
