@@ -27,6 +27,7 @@
 
 #include "goalogging.h"
 #include "goaprovider.h"
+#include "goaprovider-priv.h"
 #include "goakerberosprovider.h"
 #include "goaeditablelabel.h"
 #include "goautils.h"
@@ -68,6 +69,7 @@ struct _GoaKerberosProviderClass
  */
 
 G_DEFINE_TYPE_WITH_CODE (GoaKerberosProvider, goa_kerberos_provider, GOA_TYPE_PROVIDER,
+                         goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
                                                          g_define_type_id,
                                                          "kerberos",
