@@ -53,6 +53,7 @@ struct _GoaSmtpAuthPlain
 
   GoaProvider *provider;
   GoaObject *object;
+  gboolean auth_supported;
   gchar *domain;
   gchar *username;
   gchar *password;
@@ -74,6 +75,7 @@ enum
   PROP_PASSWORD
 };
 
+static gboolean goa_smtp_auth_plain_is_needed (GoaMailAuth        *_auth);
 static gboolean goa_smtp_auth_plain_run_sync (GoaMailAuth         *_auth,
                                               GDataInputStream    *input,
                                               GDataOutputStream   *output,
@@ -190,6 +192,7 @@ goa_smtp_auth_plain_class_init (GoaSmtpAuthPlainClass *klass)
   gobject_class->set_property = goa_smtp_auth_plain_set_property;
 
   auth_class = GOA_MAIL_AUTH_CLASS (klass);
+  auth_class->is_needed = goa_smtp_auth_plain_is_needed;
   auth_class->run_sync = goa_smtp_auth_plain_run_sync;
 
   /**
@@ -322,6 +325,15 @@ goa_smtp_auth_plain_new (GoaProvider       *provider,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
+static gboolean
+goa_smtp_auth_plain_is_needed (GoaMailAuth *_auth)
+{
+  GoaSmtpAuthPlain *auth = GOA_SMTP_AUTH_PLAIN (_auth);
+  return auth->auth_supported;
+}
+
+/* ---------------------------------------------------------------------------------------------------- */
+
 static gboolean
 goa_smtp_auth_plain_run_sync (GoaMailAuth         *_auth,
                               GDataInputStream    *input,
@@ -330,6 +342,7 @@ goa_smtp_auth_plain_run_sync (GoaMailAuth         *_auth,
                               GError             **error)
 {
   GoaSmtpAuthPlain *auth = GOA_SMTP_AUTH_PLAIN (_auth);
+  gboolean plain_supported;
   gboolean ret;
   gchar *auth_arg_base64;
   gchar *auth_arg_plain;
@@ -339,6 +352,7 @@ goa_smtp_auth_plain_run_sync (GoaMailAuth         *_auth,
   gchar *response;
   gsize auth_arg_plain_len;
 
+  plain_supported = FALSE;
   auth_arg_base64 = NULL;
   auth_arg_plain = NULL;
   domain = NULL;
@@ -430,6 +444,7 @@ goa_smtp_auth_plain_run_sync (GoaMailAuth         *_auth,
   response = g_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
+  g_debug ("< %s", response);
   if (g_str_has_prefix (response, "421"))
     {
       g_set_error (error,
@@ -452,6 +467,7 @@ goa_smtp_auth_plain_run_sync (GoaMailAuth         *_auth,
   /* Send EHLO */
 
   request = g_strdup_printf ("EHLO %s\r\n", domain);
+  g_debug ("> %s", request);
   if (!g_data_output_stream_put_string (output, request, cancellable, error))
     goto out;
   g_clear_pointer (&request, g_free);
@@ -462,12 +478,43 @@ goa_smtp_auth_plain_run_sync (GoaMailAuth         *_auth,
   response = g_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
-  if (!g_str_has_prefix (response, "250-AUTH"))
+  g_debug ("< %s", response);
+  if (g_str_has_prefix (response, "421"))
+    {
+      g_set_error (error,
+                   GOA_ERROR,
+                   GOA_ERROR_FAILED, /* TODO: more specific */
+                   _("Service not available"));
+      goto out;
+    }
+  if (!g_str_has_prefix (response, "250") || strlen (response) < 4)
+    {
+      g_set_error (error,
+                   GOA_ERROR,
+                   GOA_ERROR_FAILED, /* TODO: more specific */
+                   "Unexpected response `%s' while doing PLAIN authentication",
+                   response);
+      goto out;
+    }
+
+  if (g_str_has_prefix (response + 4, "AUTH"))
+    {
+      auth->auth_supported = TRUE;
+      if (strstr (response, "PLAIN") != NULL)
+        plain_supported = TRUE;
+    }
+
+  if (response[3] == '-')
     {
       g_free (response);
       goto ehlo_again;
     }
-  if (strstr (response, "PLAIN") == NULL)
+  else if (!auth->auth_supported)
+    {
+      ret = TRUE;
+      goto out;
+    }
+  else if (!plain_supported)
     {
       g_set_error (error,
                    GOA_ERROR,
@@ -484,19 +531,15 @@ goa_smtp_auth_plain_run_sync (GoaMailAuth         *_auth,
   auth_arg_base64 = g_base64_encode ((guchar *) auth_arg_plain, auth_arg_plain_len);
 
   request = g_strdup_printf ("AUTH PLAIN %s\r\n", auth_arg_base64);
+  g_debug ("> AUTH PLAN ********************");
   if (!g_data_output_stream_put_string (output, request, cancellable, error))
     goto out;
   g_clear_pointer (&request, g_free);
 
- auth_again:
   response = g_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
-  if (g_str_has_prefix (response, "250"))
-    {
-      g_free (response);
-      goto auth_again;
-    }
+  g_debug ("< %s", response);
   if (!g_str_has_prefix (response, "235"))
     {
       g_set_error (error,
