@@ -27,6 +27,7 @@
 #include <json-glib/json-glib.h>
 
 #include "goaprovider.h"
+#include "goaprovider-priv.h"
 #include "goaoauthprovider.h"
 #include "goayahooprovider.h"
 
@@ -58,6 +59,7 @@ struct _GoaYahooProviderClass
  */
 
 G_DEFINE_TYPE_WITH_CODE (GoaYahooProvider, goa_yahoo_provider, GOA_TYPE_OAUTH_PROVIDER,
+                         goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
 							 g_define_type_id,
 							 "yahoo",
